Represents an ‘access point’ for the share.
Central instance to access all Baremetalsolution related resource activities
Message for detach specific LUN from an Instance.
Message for disabling the interactive serial console on an instance.
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
Message for enabling the interactive serial console on an instance.
Request for skip lun cooloff and delete it.
Request for skip volume cooloff and delete it.
Each logical interface represents a logical abstraction of the underlying physical interface (for eg. bond, nic) of the instance. Each logical interface can effectively map to multiple network-IP pairs and still be mapped to one underlying physical interface.
A server.
Configuration parameters for a new instance.
A resource budget.
A GCP vlan attachment.
Response message for the list of servers.
The response message for Locations.ListLocations.
Response message containing the list of storage volume luns.
Response with Networks with IPs
Response message containing the list of networks.
Response message containing the list of NFS shares.
Request for getting all available OS images.
Response message for the list of provisioning quotas.
Message for response of ListSSHKeys.
Response message containing the list of volume snapshots.
Response message containing the list of storage volumes.
Response for LoadInstanceAuthInfo.
A resource that represents a Google Cloud location.
Each logical network interface is effectively a network and IP pair.
A storage volume logical unit number (LUN).
A LUN(Logical Unit Number) range.
A Network.
A network.
A reservation of one or more addresses in a network.
Configuration parameters for a new network.
Mount point for a network.
Network with all used IP addresses.
A NFS export entry.
An NFS share.
Operation System image.
This resource represents a long-running operation that is the result of a network API call.
Gets information about a location.
Detach LUN from Instance.
Disable the interactive serial console feature on an instance.
Enable the interactive serial console feature on an instance.
Get details about a single server.
List servers in a given project and location.
Load auth info for a server.
Update details of a single server.
RenameInstance sets a new name for an instance. Use with caution, previous names become immediately invalidated.
Perform an ungraceful, hard reset on a server. Equivalent to shutting the power off and then turning it back on.
Starts a server that was shutdown.
Stop a running server.
Lists information about the supported locations for this service.
Get details of a single network.
List network in a given project and location.
List all Networks (and used IPs for each Network) in the vendor account associated with the specified project.
Update details of a single network.
RenameNetwork sets a new name for a network. Use with caution, previous names become immediately invalidated.
Create an NFS share.
Delete an NFS share. The underlying volume is automatically deleted.
Get details of a single NFS share.
List NFS shares.
Update details of a single NFS share.
RenameNfsShare sets a new name for an nfsshare. Use with caution, previous names become immediately invalidated.
Get details about an operation.
Get details of a single OS image.
Retrieves the list of OS images which are currently approved.
Create new ProvisioningConfig.
Get ProvisioningConfig by name.
Update existing ProvisioningConfig.
Submit a provisiong configuration for a given project.
List the budget details to provision resources on a given project.
Register a public SSH key in the specified project for use with the interactive serial console feature.
Deletes a public SSH key registered in the specified project.
Lists the public SSH keys registered for the specified project. These SSH keys are used only for the interactive serial console feature.
Skips volume’s cooloff and deletes it now. Volume must be in cooloff state.
Get details of a single storage volume.
List storage volumes in a given project and location.
Skips lun’s cooloff and deletes it now. Lun must be in cooloff state.
Get details of a single storage logical unit number(LUN).
List storage volume luns for given storage volume.
Update details of a single storage volume.
RenameVolume sets a new name for a volume. Use with caution, previous names become immediately invalidated.
Emergency Volume resize.
Takes a snapshot of a boot volume. Returns INVALID_ARGUMENT if called for a non-boot volume.
Deletes a volume snapshot. Returns INVALID_ARGUMENT if called for a non-boot volume.
Returns the specified snapshot resource. Returns INVALID_ARGUMENT if called for a non-boot volume.
Retrieves the list of snapshots for the specified volume. Returns a response with an empty list of snapshots if called for a non-boot volume.
Uses the specified snapshot to restore its parent volume. Returns INVALID_ARGUMENT if called for a non-boot volume.
A builder providing access to all methods supported on
project resources.
It is not used directly, but through the
Baremetalsolution hub.
A provisioning configuration.
A provisioning quota for a given project.
QOS policy parameters.
Message requesting rename of a server.
Message requesting rename of a server.
Message requesting rename of a server.
Message requesting rename of a server.
Message requesting to reset a server.
Request for emergency resize Volume.
Message for restoring a volume snapshot.
An SSH key, used for authorizing with the interactive serial console feature.
Details about snapshot space reservation and usage on the storage volume.
Message requesting to start a server.
The
Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each
Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the
API Design Guide.
Message requesting to stop a server.
Request for SubmitProvisioningConfig.
Response for SubmitProvisioningConfig.
User account provisioned for the customer.
A network VRF.
VLAN attachment details.
A storage volume.
Configuration parameters for a new volume.
A snapshot of a volume. Only boot volumes can have snapshots.