pub struct ProjectMethods<'a, S>
where S: 'a,
{ /* private fields */ }
A builder providing access to all methods supported on project resources. It is not used directly, but through the Baremetalsolution hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate google_baremetalsolution2 as baremetalsolution2;
 
use std::default::Default;
use baremetalsolution2::{Baremetalsolution, oauth2, hyper, hyper_rustls, chrono, FieldMask};
 
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
        secret,
        oauth2::InstalledFlowReturnMethod::HTTPRedirect,
    ).build().await.unwrap();
let mut hub = Baremetalsolution::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `locations_get(...)`, `locations_instances_detach_lun(...)`, `locations_instances_disable_interactive_serial_console(...)`, `locations_instances_enable_interactive_serial_console(...)`, `locations_instances_get(...)`, `locations_instances_list(...)`, `locations_instances_load_auth_info(...)`, `locations_instances_patch(...)`, `locations_instances_rename(...)`, `locations_instances_reset(...)`, `locations_instances_start(...)`, `locations_instances_stop(...)`, `locations_list(...)`, `locations_networks_get(...)`, `locations_networks_list(...)`, `locations_networks_list_network_usage(...)`, `locations_networks_patch(...)`, `locations_networks_rename(...)`, `locations_nfs_shares_create(...)`, `locations_nfs_shares_delete(...)`, `locations_nfs_shares_get(...)`, `locations_nfs_shares_list(...)`, `locations_nfs_shares_patch(...)`, `locations_nfs_shares_rename(...)`, `locations_operations_get(...)`, `locations_os_images_get(...)`, `locations_os_images_list(...)`, `locations_provisioning_configs_create(...)`, `locations_provisioning_configs_get(...)`, `locations_provisioning_configs_patch(...)`, `locations_provisioning_configs_submit(...)`, `locations_provisioning_quotas_list(...)`, `locations_ssh_keys_create(...)`, `locations_ssh_keys_delete(...)`, `locations_ssh_keys_list(...)`, `locations_volumes_evict(...)`, `locations_volumes_get(...)`, `locations_volumes_list(...)`, `locations_volumes_luns_evict(...)`, `locations_volumes_luns_get(...)`, `locations_volumes_luns_list(...)`, `locations_volumes_patch(...)`, `locations_volumes_rename(...)`, `locations_volumes_resize(...)`, `locations_volumes_snapshots_create(...)`, `locations_volumes_snapshots_delete(...)`, `locations_volumes_snapshots_get(...)`, `locations_volumes_snapshots_list(...)` and `locations_volumes_snapshots_restore_volume_snapshot(...)`
// to build up your call.
let rb = hub.projects();

Implementations

source

impl<'a, S> ProjectMethods<'a, S>

source

pub fn locations_instances_detach_lun( &self, request: DetachLunRequest, instance: &str ) -> ProjectLocationInstanceDetachLunCall<'a, S>

Create a builder to help you perform the following task:

Detach LUN from Instance.

Arguments
  • request - No description provided.
  • instance - Required. Name of the instance.
source

pub fn locations_instances_disable_interactive_serial_console( &self, request: DisableInteractiveSerialConsoleRequest, name: &str ) -> ProjectLocationInstanceDisableInteractiveSerialConsoleCall<'a, S>

Create a builder to help you perform the following task:

Disable the interactive serial console feature on an instance.

Arguments
  • request - No description provided.
  • name - Required. Name of the resource.
source

pub fn locations_instances_enable_interactive_serial_console( &self, request: EnableInteractiveSerialConsoleRequest, name: &str ) -> ProjectLocationInstanceEnableInteractiveSerialConsoleCall<'a, S>

Create a builder to help you perform the following task:

Enable the interactive serial console feature on an instance.

Arguments
  • request - No description provided.
  • name - Required. Name of the resource.
source

pub fn locations_instances_get( &self, name: &str ) -> ProjectLocationInstanceGetCall<'a, S>

Create a builder to help you perform the following task:

Get details about a single server.

Arguments
  • name - Required. Name of the resource.
source

pub fn locations_instances_list( &self, parent: &str ) -> ProjectLocationInstanceListCall<'a, S>

Create a builder to help you perform the following task:

List servers in a given project and location.

Arguments
  • parent - Required. Parent value for ListInstancesRequest.
source

pub fn locations_instances_load_auth_info( &self, name: &str ) -> ProjectLocationInstanceLoadAuthInfoCall<'a, S>

Create a builder to help you perform the following task:

Load auth info for a server.

Arguments
  • name - Required. Name of the server.
source

pub fn locations_instances_patch( &self, request: Instance, name: &str ) -> ProjectLocationInstancePatchCall<'a, S>

Create a builder to help you perform the following task:

Update details of a single server.

Arguments
  • request - No description provided.
  • name - Immutable. The resource name of this Instance. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. Format: projects/{project}/locations/{location}/instances/{instance}
source

pub fn locations_instances_rename( &self, request: RenameInstanceRequest, name: &str ) -> ProjectLocationInstanceRenameCall<'a, S>

Create a builder to help you perform the following task:

RenameInstance sets a new name for an instance. Use with caution, previous names become immediately invalidated.

Arguments
  • request - No description provided.
  • name - Required. The name field is used to identify the instance. Format: projects/{project}/locations/{location}/instances/{instance}
source

pub fn locations_instances_reset( &self, request: ResetInstanceRequest, name: &str ) -> ProjectLocationInstanceResetCall<'a, S>

Create a builder to help you perform the following task:

Perform an ungraceful, hard reset on a server. Equivalent to shutting the power off and then turning it back on.

Arguments
  • request - No description provided.
  • name - Required. Name of the resource.
source

pub fn locations_instances_start( &self, request: StartInstanceRequest, name: &str ) -> ProjectLocationInstanceStartCall<'a, S>

Create a builder to help you perform the following task:

Starts a server that was shutdown.

Arguments
  • request - No description provided.
  • name - Required. Name of the resource.
source

pub fn locations_instances_stop( &self, request: StopInstanceRequest, name: &str ) -> ProjectLocationInstanceStopCall<'a, S>

Create a builder to help you perform the following task:

Stop a running server.

Arguments
  • request - No description provided.
  • name - Required. Name of the resource.
source

pub fn locations_networks_get( &self, name: &str ) -> ProjectLocationNetworkGetCall<'a, S>

Create a builder to help you perform the following task:

Get details of a single network.

Arguments
  • name - Required. Name of the resource.
source

pub fn locations_networks_list( &self, parent: &str ) -> ProjectLocationNetworkListCall<'a, S>

Create a builder to help you perform the following task:

List network in a given project and location.

Arguments
  • parent - Required. Parent value for ListNetworksRequest.
source

pub fn locations_networks_list_network_usage( &self, location: &str ) -> ProjectLocationNetworkListNetworkUsageCall<'a, S>

Create a builder to help you perform the following task:

List all Networks (and used IPs for each Network) in the vendor account associated with the specified project.

Arguments
  • location - Required. Parent value (project and location).
source

pub fn locations_networks_patch( &self, request: Network, name: &str ) -> ProjectLocationNetworkPatchCall<'a, S>

Create a builder to help you perform the following task:

Update details of a single network.

Arguments
  • request - No description provided.
  • name - Output only. The resource name of this Network. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. Format: projects/{project}/locations/{location}/networks/{network}
source

pub fn locations_networks_rename( &self, request: RenameNetworkRequest, name: &str ) -> ProjectLocationNetworkRenameCall<'a, S>

Create a builder to help you perform the following task:

RenameNetwork sets a new name for a network. Use with caution, previous names become immediately invalidated.

Arguments
  • request - No description provided.
  • name - Required. The name field is used to identify the network. Format: projects/{project}/locations/{location}/networks/{network}
source

pub fn locations_nfs_shares_create( &self, request: NfsShare, parent: &str ) -> ProjectLocationNfsShareCreateCall<'a, S>

Create a builder to help you perform the following task:

Create an NFS share.

Arguments
  • request - No description provided.
  • parent - Required. The parent project and location.
source

pub fn locations_nfs_shares_delete( &self, name: &str ) -> ProjectLocationNfsShareDeleteCall<'a, S>

Create a builder to help you perform the following task:

Delete an NFS share. The underlying volume is automatically deleted.

Arguments
  • name - Required. The name of the NFS share to delete.
source

pub fn locations_nfs_shares_get( &self, name: &str ) -> ProjectLocationNfsShareGetCall<'a, S>

Create a builder to help you perform the following task:

Get details of a single NFS share.

Arguments
  • name - Required. Name of the resource.
source

pub fn locations_nfs_shares_list( &self, parent: &str ) -> ProjectLocationNfsShareListCall<'a, S>

Create a builder to help you perform the following task:

List NFS shares.

Arguments
  • parent - Required. Parent value for ListNfsSharesRequest.
source

pub fn locations_nfs_shares_patch( &self, request: NfsShare, name: &str ) -> ProjectLocationNfsSharePatchCall<'a, S>

Create a builder to help you perform the following task:

Update details of a single NFS share.

Arguments
  • request - No description provided.
  • name - Immutable. The name of the NFS share.
source

pub fn locations_nfs_shares_rename( &self, request: RenameNfsShareRequest, name: &str ) -> ProjectLocationNfsShareRenameCall<'a, S>

Create a builder to help you perform the following task:

RenameNfsShare sets a new name for an nfsshare. Use with caution, previous names become immediately invalidated.

Arguments
  • request - No description provided.
  • name - Required. The name field is used to identify the nfsshare. Format: projects/{project}/locations/{location}/nfsshares/{nfsshare}
source

pub fn locations_operations_get( &self, name: &str ) -> ProjectLocationOperationGetCall<'a, S>

Create a builder to help you perform the following task:

Get details about an operation.

Arguments
  • name - The name of the operation resource.
source

pub fn locations_os_images_get( &self, name: &str ) -> ProjectLocationOsImageGetCall<'a, S>

Create a builder to help you perform the following task:

Get details of a single OS image.

Arguments
  • name - Required. Name of the OS image.
source

pub fn locations_os_images_list( &self, parent: &str ) -> ProjectLocationOsImageListCall<'a, S>

Create a builder to help you perform the following task:

Retrieves the list of OS images which are currently approved.

Arguments
  • parent - Required. Parent value for ListOSImagesRequest.
source

pub fn locations_provisioning_configs_create( &self, request: ProvisioningConfig, parent: &str ) -> ProjectLocationProvisioningConfigCreateCall<'a, S>

Create a builder to help you perform the following task:

Create new ProvisioningConfig.

Arguments
  • request - No description provided.
  • parent - Required. The parent project and location containing the ProvisioningConfig.
source

pub fn locations_provisioning_configs_get( &self, name: &str ) -> ProjectLocationProvisioningConfigGetCall<'a, S>

Create a builder to help you perform the following task:

Get ProvisioningConfig by name.

Arguments
  • name - Required. Name of the ProvisioningConfig.
source

pub fn locations_provisioning_configs_patch( &self, request: ProvisioningConfig, name: &str ) -> ProjectLocationProvisioningConfigPatchCall<'a, S>

Create a builder to help you perform the following task:

Update existing ProvisioningConfig.

Arguments
  • request - No description provided.
  • name - Output only. The system-generated name of the provisioning config. This follows the UUID format.
source

pub fn locations_provisioning_configs_submit( &self, request: SubmitProvisioningConfigRequest, parent: &str ) -> ProjectLocationProvisioningConfigSubmitCall<'a, S>

Create a builder to help you perform the following task:

Submit a provisiong configuration for a given project.

Arguments
  • request - No description provided.
  • parent - Required. The parent project and location containing the ProvisioningConfig.
source

pub fn locations_provisioning_quotas_list( &self, parent: &str ) -> ProjectLocationProvisioningQuotaListCall<'a, S>

Create a builder to help you perform the following task:

List the budget details to provision resources on a given project.

Arguments
  • parent - Required. Parent value for ListProvisioningQuotasRequest.
source

pub fn locations_ssh_keys_create( &self, request: SSHKey, parent: &str ) -> ProjectLocationSshKeyCreateCall<'a, S>

Create a builder to help you perform the following task:

Register a public SSH key in the specified project for use with the interactive serial console feature.

Arguments
  • request - No description provided.
  • parent - Required. The parent containing the SSH keys.
source

pub fn locations_ssh_keys_delete( &self, name: &str ) -> ProjectLocationSshKeyDeleteCall<'a, S>

Create a builder to help you perform the following task:

Deletes a public SSH key registered in the specified project.

Arguments
  • name - Required. The name of the SSH key to delete. Currently, the only valid value for the location is “global”.
source

pub fn locations_ssh_keys_list( &self, parent: &str ) -> ProjectLocationSshKeyListCall<'a, S>

Create a builder to help you perform the following task:

Lists the public SSH keys registered for the specified project. These SSH keys are used only for the interactive serial console feature.

Arguments
  • parent - Required. The parent containing the SSH keys. Currently, the only valid value for the location is “global”.
source

pub fn locations_volumes_luns_evict( &self, request: EvictLunRequest, name: &str ) -> ProjectLocationVolumeLunEvictCall<'a, S>

Create a builder to help you perform the following task:

Skips lun’s cooloff and deletes it now. Lun must be in cooloff state.

Arguments
  • request - No description provided.
  • name - Required. The name of the lun.
source

pub fn locations_volumes_luns_get( &self, name: &str ) -> ProjectLocationVolumeLunGetCall<'a, S>

Create a builder to help you perform the following task:

Get details of a single storage logical unit number(LUN).

Arguments
  • name - Required. Name of the resource.
source

pub fn locations_volumes_luns_list( &self, parent: &str ) -> ProjectLocationVolumeLunListCall<'a, S>

Create a builder to help you perform the following task:

List storage volume luns for given storage volume.

Arguments
  • parent - Required. Parent value for ListLunsRequest.
source

pub fn locations_volumes_snapshots_create( &self, request: VolumeSnapshot, parent: &str ) -> ProjectLocationVolumeSnapshotCreateCall<'a, S>

Create a builder to help you perform the following task:

Takes a snapshot of a boot volume. Returns INVALID_ARGUMENT if called for a non-boot volume.

Arguments
  • request - No description provided.
  • parent - Required. The volume to snapshot.
source

pub fn locations_volumes_snapshots_delete( &self, name: &str ) -> ProjectLocationVolumeSnapshotDeleteCall<'a, S>

Create a builder to help you perform the following task:

Deletes a volume snapshot. Returns INVALID_ARGUMENT if called for a non-boot volume.

Arguments
  • name - Required. The name of the snapshot to delete.
source

pub fn locations_volumes_snapshots_get( &self, name: &str ) -> ProjectLocationVolumeSnapshotGetCall<'a, S>

Create a builder to help you perform the following task:

Returns the specified snapshot resource. Returns INVALID_ARGUMENT if called for a non-boot volume.

Arguments
  • name - Required. The name of the snapshot.
source

pub fn locations_volumes_snapshots_list( &self, parent: &str ) -> ProjectLocationVolumeSnapshotListCall<'a, S>

Create a builder to help you perform the following task:

Retrieves the list of snapshots for the specified volume. Returns a response with an empty list of snapshots if called for a non-boot volume.

Arguments
  • parent - Required. Parent value for ListVolumesRequest.
source

pub fn locations_volumes_snapshots_restore_volume_snapshot( &self, request: RestoreVolumeSnapshotRequest, volume_snapshot: &str ) -> ProjectLocationVolumeSnapshotRestoreVolumeSnapshotCall<'a, S>

Create a builder to help you perform the following task:

Uses the specified snapshot to restore its parent volume. Returns INVALID_ARGUMENT if called for a non-boot volume.

Arguments
  • request - No description provided.
  • volumeSnapshot - Required. Name of the snapshot which will be used to restore its parent volume.
source

pub fn locations_volumes_evict( &self, request: EvictVolumeRequest, name: &str ) -> ProjectLocationVolumeEvictCall<'a, S>

Create a builder to help you perform the following task:

Skips volume’s cooloff and deletes it now. Volume must be in cooloff state.

Arguments
  • request - No description provided.
  • name - Required. The name of the Volume.
source

pub fn locations_volumes_get( &self, name: &str ) -> ProjectLocationVolumeGetCall<'a, S>

Create a builder to help you perform the following task:

Get details of a single storage volume.

Arguments
  • name - Required. Name of the resource.
source

pub fn locations_volumes_list( &self, parent: &str ) -> ProjectLocationVolumeListCall<'a, S>

Create a builder to help you perform the following task:

List storage volumes in a given project and location.

Arguments
  • parent - Required. Parent value for ListVolumesRequest.
source

pub fn locations_volumes_patch( &self, request: Volume, name: &str ) -> ProjectLocationVolumePatchCall<'a, S>

Create a builder to help you perform the following task:

Update details of a single storage volume.

Arguments
  • request - No description provided.
  • name - Output only. The resource name of this Volume. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. Format: projects/{project}/locations/{location}/volumes/{volume}
source

pub fn locations_volumes_rename( &self, request: RenameVolumeRequest, name: &str ) -> ProjectLocationVolumeRenameCall<'a, S>

Create a builder to help you perform the following task:

RenameVolume sets a new name for a volume. Use with caution, previous names become immediately invalidated.

Arguments
  • request - No description provided.
  • name - Required. The name field is used to identify the volume. Format: projects/{project}/locations/{location}/volumes/{volume}
source

pub fn locations_volumes_resize( &self, request: ResizeVolumeRequest, volume: &str ) -> ProjectLocationVolumeResizeCall<'a, S>

Create a builder to help you perform the following task:

Emergency Volume resize.

Arguments
  • request - No description provided.
  • volume - Required. Volume to resize.
source

pub fn locations_get(&self, name: &str) -> ProjectLocationGetCall<'a, S>

Create a builder to help you perform the following task:

Gets information about a location.

Arguments
  • name - Resource name for the location.
source

pub fn locations_list(&self, name: &str) -> ProjectLocationListCall<'a, S>

Create a builder to help you perform the following task:

Lists information about the supported locations for this service.

Arguments
  • name - The resource that owns the locations collection, if applicable.